@@ -4,8 +4,8 @@ import json
 import mimetypes
 import shutil
 import subprocess
-import sys
 from enum import Enum
+from importlib.metadata import version
 from pathlib import Path
 from subprocess import CalledProcessError
 from typing import Any, Dict, List, Optional, Sequence, Union
@@ -21,11 +21,6 @@ from .config import Config
 from .parser import GeneratorData, import_string_from_class
 from .parser.errors import ErrorLevel, GeneratorError
 
-if sys.version_info.minor < 8:  # version did not exist before 3.8, need to use a backport
-    from importlib_metadata import version
-else:
-    from importlib.metadata import version  # type: ignore
-
 __version__ = version(__package__)
 
 
@@ -310,7 +305,7 @@ def _get_project_for_url_or_path(  # pylint: disable=too-many-arguments
     custom_template_path: Optional[Path] = None,
     file_encoding: str = "utf-8",
 ) -> Union[Project, GeneratorError]:
-    data_dict = _get_document(url=url, path=path)
+    data_dict = _get_document(url=url, path=path, timeout=config.http_timeout)
     if isinstance(data_dict, GeneratorError):
         return data_dict
     openapi = GeneratorData.from_dict(data_dict, config=config)
@@ -394,14 +389,14 @@ def _load_yaml_or_json(data: bytes, content_type: Optional[str]) -> Union[Dict[s
             return GeneratorError(header=f"Invalid YAML from provided source: {err}")
 
 
-def _get_document(*, url: Optional[str], path: Optional[Path]) -> Union[Dict[str, Any], GeneratorError]:
+def _get_document(*, url: Optional[str], path: Optional[Path], timeout: int) -> Union[Dict[str, Any], GeneratorError]:
     yaml_bytes: bytes
     content_type: Optional[str]
     if url is not None and path is not None:
         return GeneratorError(header="Provide URL or Path, not both.")
     if url is not None:
         try:
-            response = httpx.get(url)
+            response = httpx.get(url, timeout=timeout)
             yaml_bytes = response.content
             if "content-type" in response.headers:
                 content_type = response.headers["content-type"].split(";")[0]
